@@ -48,7 +48,7 @@ _db_table_type = None
 
 
 if TYPE_CHECKING:
-    import colemen_utilities.database_utils.MySQLDatabase as _mysqldb
+    import colemen_utilities.database_utils.MySQL.MySQLDatabase as _mysqldb
     _db_mysql_database_type = _TypeVar('_db_mysql_database_type', bound=_mysqldb.MySQLDatabase)
     import colemen_utilities.database_utils.MySQL.Column.Column as _col
     _db_column_type = _TypeVar('_db_column_type', bound=_col.Column)
