@@ -1,19 +1,24 @@
-# pylint: disable=missing-function-docstring
+
 # pylint: disable=missing-class-docstring
 # pylint: disable=line-too-long
 # pylint: disable=unused-wildcard-import
 # pylint: disable=wildcard-import
 # pylint: disable=unused-import
+
+
 '''
-    A module of utility methods used for parsing and converting python types.
+    Module containing the MySQLDatabase class declaration.
+
+    This is used to connect to a remote MySQL database and allows slightly abstracted
+    methods for manipulating it.
 
     ----------
 
     Meta
     ----------
     `author`: Colemen Atwood
-    `created`: 06-03-2022 10:22:15
-    `memberOf`: type_utils
+    `created`: 12-13-2022 12:42:25
+    `memberOf`: MySQL
 '''
 
 
@@ -21,12 +26,12 @@ import datetime
 from dataclasses import dataclass
 import json
 import re as re
-import os as _os
-from re import L
+import os
+
 import sys
-import time
+
 from typing import Iterable, Union as _Union
-from typing import Iterable as _Iterable
+
 
 import mysql.connector as _mysqlConnector
 import traceback as _traceback
@@ -35,10 +40,10 @@ from colorama import Fore as _Fore
 from colorama import Style as _Style
 from colemen_config import _db_column_type,_db_table_type,_db_mysql_delete_query_type,_db_mysql_select_query_type,_db_mysql_update_query_type
 import colemen_utilities.dict_utils as _obj
-import colemen_utilities.file_utils as _cfu
-import colemen_utilities.directory_utils as _dirs
+# import colemen_utilities.file_utils as _cfu
+# import colemen_utilities.directory_utils as _dirs
 import colemen_utilities.string_utils as _csu
-import colemen_utilities.list_utils as _lu
+# import colemen_utilities.list_utils as _lu
 from colemen_utilities.database_utils.MySQL.SelectQuery import SelectQuery
 from colemen_utilities.database_utils.MySQL.UpdateQuery import UpdateQuery
 from colemen_utilities.database_utils.MySQL.DeleteQuery import DeleteQuery
@@ -67,12 +72,46 @@ class MySQLDatabase:
 
 
     def __init__(self,**kwargs):
+        '''
+            Create a new MySQL database connection.
+            ----------
+
+
+            Keyword Arguments
+            -------------------------
+            `database` {str}
+                The name of the database/schema this instance represents.
+
+            `user` {str}
+                The user name used to connect to the database.
+
+            `password` {str}
+                The password used to connect to the database.
+
+            `host` {str}
+                The host address used to connect to the database
+
+            `cache_path` {str}
+                The path to the directory where the table cache files can be saved.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:30:55
+            `memberOf`: MySQLDatabase
+            `version`: 1.0
+            `method_name`: MySQLDatabase
+            * @xxx [12-13-2022 12:31:27]: documentation for MySQLDatabase
+        '''
+        
+        
         self._dbm = None
         '''The Database manager instance.'''
 
         self.database:str = _obj.get_kwarg(['database','name'],None,(str),**kwargs)
         '''The name of the database/schema this instance represents.'''
 
+
         self.user:str = _obj.get_kwarg(['user'],None,(str),**kwargs)
         '''The user name used to connect to the database.'''
 
@@ -82,6 +121,9 @@ class MySQLDatabase:
         self.host:str = _obj.get_kwarg(['host'],None,(str),**kwargs)
         '''The host address used to connect to the database'''
 
+        self.cache_path:str = _obj.get_kwarg(['cache_path'],f"{os.getcwd()}/db_cache",(str),**kwargs)
+        '''The path to the directory where the table cache files can be saved.'''
+
         self._credentials:bool = None
         '''True if the credentials dictionary can be successfully compiled.'''
 
@@ -365,16 +407,44 @@ class MySQLDatabase:
 
 
     def insert_to_table(self,table_name:str,data:dict):
+        '''
+            Insert a dictionary of data into the table specified
+            ----------
+
+            Arguments
+            -------------------------
+            `table_name` {str}
+                The name of the table to insert the data into.
+            `data` {dict}
+                A dictionary of data to insert, the keys corresponding to columns in the table.
+
+            Return {int,bool}
+            ----------------------
+            The integer id of the inserted row if successful, False otherwise.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 11:44:48
+            `memberOf`: MySQLDatabase
+            `version`: 1.0
+            `method_name`: insert_to_table
+            * @xxx [12-13-2022 11:46:06]: documentation for insert_to_table
+        '''
+        tb = self.get_table(table_name)
         data = self.correlate_to_table(table_name,data,crud="create",cerberus_validate=True)
         from colemen_utilities.sql_utils import insert_from_dict
         if len(data.keys()) == 0:
+            _log("No keys in the data dict were correlated to columns in the table.","warning")
             return False
         sql,args = insert_from_dict(data,table_name,self.database)
-        print(f"sql: {sql}")
-        print(f"args: {args}")
+        # print(f"sql: {sql}")
+        # print(f"args: {args}")
         result = self.run(sql,args)
         if result is True:
             return self.last_id()
+        _log("Failed to execute SQL.","warning")
+        return False
 
     def select_query(self,table_name:str)->_db_mysql_select_query_type:
         '''Create a new select query instance'''
@@ -667,11 +737,11 @@ class MySQLDatabase:
                     tmp[col] = row[col]
                 new_data.append(tmp)
             return new_data
-        if isinstance(result, sqlite3.Row):
-            new_data = {}
-            for col in result.keys():
-                new_data[col] = result[col]
-            return new_data
+        # if isinstance(result, sqlite3.Row):
+        #     new_data = {}
+        #     for col in result.keys():
+        #         new_data[col] = result[col]
+        #     return new_data
 
     def last_id(self):
         sql = 'SELECT LAST_INSERT_ID();'
@@ -914,6 +984,29 @@ class MySQLDatabase:
         return output
 
     def get_table(self,table_name:str)->_db_table_type:
+        '''
+            Retrieve a table from this database by its name.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `table_name` {str}
+                The name of the table to retrieve
+
+            Return {Table}
+            ----------------------
+            The MySQL Table instance if the table exists, None otherwise.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:17:47
+            `memberOf`: MySQLDatabase
+            `version`: 1.0
+            `method_name`: get_table
+            * @xxx [12-13-2022 12:19:06]: documentation for get_table
+        '''
         # @Mstep [IF] if the table already exists in the _tables dictionary.
         if table_name in self._tables:
             # @Mstep [RETURN] return table
@@ -1232,6 +1325,42 @@ def _sanitize_args(args):
 
 
 def new(**kwargs)->MySQLDatabase:
+    '''
+        Create a new MySQL database connection.
+
+        ----------
+
+
+        Keyword Arguments
+        -------------------------
+        `database` {str}
+            The name of the database/schema this instance represents.
+
+        `user` {str}
+            The user name used to connect to the database.
+
+        `password` {str}
+            The password used to connect to the database.
+
+        `host` {str}
+            The host address used to connect to the database
+
+        `cache_path` {str}
+            The path to the directory where the table cache files can be saved.
+
+        Return {MySQLDatabase}
+        ----------------------
+        The MySQLDatabase instance.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2022 12:27:05
+        `memberOf`: MySQLDatabase
+        `version`: 1.0
+        `method_name`: new
+        * @xxx [12-13-2022 12:29:29]: documentation for new
+    '''
     return MySQLDatabase(**kwargs)
 
 
