@@ -53,10 +53,18 @@ _log = _con.log
 @dataclass
 class SelectQuery:
     table_name:str = None
+    '''The name of the table that this query is for.'''
     schema_name:str = None
+    '''The name of the schema that the table belongs to.'''
+
     limit:int = 100
+    '''The limit of how many results are allowed to be returned.'''
+
     offset:int = None
+    '''The offset of the result set.'''
+
     statement:str = None
+
     args = None
     database:_db_mysql_database_type = None
     _count:bool = False
@@ -86,18 +94,45 @@ class SelectQuery:
             self.schema_name = self.database.database
             self.limit = self.database.get_limit
 
-    def execute(self):
+    def execute(self,default=None):
+        '''
+            Execute this query's SQL and return its results.
+            ----------
+
+            Arguments
+            -------------------------
+            [`default`=None] {any}
+                The default value to return if nothing is found.
+
+
+            Return {any}
+            ----------------------
+            The results of the query if successful, the default value otherwise.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:12:16
+            `memberOf`: SelectQuery
+            `version`: 1.0
+            `method_name`: execute
+            * @xxx [12-13-2022 12:14:14]: documentation for execute
+        '''
         if self.database is None:
             raise Exception("Select Query does not have a database to execute the query on")
         sql,args= self.query
         # print(f"sql: {sql}")
         # print(f"args: {args}")
-        return self.database.run_select(sql,args)
+        return self.database.run_select(sql,args,default=default)
 
     @property
-    def schema_table_string(self):
+    def __schema_table_string(self)->str:
         '''
-            Get this Query's schema_table_string
+            Get this Query's __schema_table_string
+
+            This is just a simple concatenation used to refer to the table and optionally its schema
+
+            `schemaName`.`tableName`
 
             `default`:None
 
@@ -107,18 +142,17 @@ class SelectQuery:
             `@author`: Colemen Atwood
             `@created`: 12-09-2022 10:47:15
             `@memberOf`: Query
-            `@property`: schema_table_string
+            `@property`: __schema_table_string
         '''
         value = f"`{self.table_name}`"
         if self.schema_name is not None:
             value = f"`{self.schema_name}`.{value}"
         return value
 
-
     @property
     def query(self):
         '''
-            Get this SelectQuery's query
+            Get the compiled and parameterized SQL query with the parameter dictionary.
 
             `default`:None
 
@@ -130,16 +164,16 @@ class SelectQuery:
             `@memberOf`: SelectQuery
             `@property`: query
         '''
-        value = f"SELECT {self.select_string} FROM {self.schema_table_string}{self.where_string}"
+        value = f"SELECT {self.select_string} FROM {self.__schema_table_string}{self.where_string}"
 
         value = _paginate_select_query(value,self.limit,self.offset)
         value = _format_query_params(value,self._params)
         return value,self._params
 
     @property
-    def where_string(self):
+    def where_string(self)->str:
         '''
-            Get this SelectQuery's where_string
+            Get the compiled where clauses for this query.
 
             `default`:None
 
@@ -190,9 +224,9 @@ class SelectQuery:
         return value
 
     @property
-    def select_string(self):
+    def select_string(self)->str:
         '''
-            Get this SelectQuery's select_string
+            Get the compiled select string for this query.
 
             `default`:None
 
@@ -227,6 +261,45 @@ class SelectQuery:
 
 
     def add_where(self,column_name,value,comparison="="):
+        '''
+            Add a where clause to the query.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `column_name` {str}
+                The name of the column to compare.
+
+            `value` {any}
+                The value that the column should match.
+
+                If the comparison is a "between", this should be a list or tuple with two values [min,max].
+
+                If the comparison is an "in", this should be a list or tuple of values.
+
+            [`comparison`="="] {str}
+                The type of comparison to perform, defaults to "="
+
+                Also supports:
+                - between
+                - in
+                - is not
+                - !=,<>,=,<,>,>=,<=
+
+            Return {None}
+            ----------------------
+            nothing.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 11:55:02
+            `memberOf`: SelectQuery
+            `version`: 1.0
+            `method_name`: add_where
+            * @xxx [12-13-2022 12:04:13]: documentation for add_where
+        '''
         if value is None:
             value = "NULL"
 
@@ -270,6 +343,32 @@ class SelectQuery:
         self._wheres.append(data)
 
     def add_select(self,column_name,alias=None):
+        '''
+            Add a column to the selection of this query.
+
+            By default "*" is used to select all columns if None are specified.
+            ----------
+
+            Arguments
+            -------------------------
+            `column_name` {str}
+                The name of the column to select
+            [`alias`=None] {str}
+                An alias to use for this column
+
+            Return {None}
+            ----------------------
+            returns nothing
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:04:31
+            `memberOf`: SelectQuery
+            `version`: 1.0
+            `method_name`: add_select
+            * @xxx [12-13-2022 12:06:00]: documentation for add_select
+        '''
         data = {
             "column_name":column_name,
             "alias":alias,
