@@ -1,5 +1,4 @@
-# pylint: disable=missing-function-docstring
-# pylint: disable=missing-class-docstring
+
 # pylint: disable=line-too-long
 # pylint: disable=unused-import
 
@@ -13,7 +12,7 @@ from typing import Iterable, Union
 
 # import colemen_utilities.database_utils.MySQL.Column.Column as _Column
 from colemen_utilities.database_utils.MySQL.Column.Column import Column as _Column
-# import colemen_utilities.database_utils.MySQL.Column.column_utils as _u
+import colemen_utilities.dict_utils as _obj
 from colemen_utilities.database_utils.MySQL.Column import column_utils as _u
 from colemen_config import _db_column_type,_db_mysql_database_type
 from colemen_utilities.database_utils.MySQL import CacheFile as _CacheFile
@@ -64,10 +63,36 @@ class Table:
 
 
     _Columns = []
+    _primary_id = None
     relationships = None
     '''A list of relationship instances that are associated to this table.'''
 
     def __init__(self,database:_db_mysql_database_type,table_name:str,data:dict = None) -> None:
+        '''
+            Create a table instance.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `database` {MySQLDatabase}
+                A reference to the Database that this table belongs to.
+
+            `table_name` {str}
+                The name of this table.
+
+            `data` {dict}
+                A dictionary of table data.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:38:23
+            `memberOf`: Table
+            `version`: 1.0
+            `method_name`: Table
+            * @TODO []: documentation for Table
+        '''
         self.database:_db_mysql_database_type = database
         self.table_name = table_name
         self._columns = []
@@ -109,6 +134,7 @@ class Table:
         return value
 
     def save_cache(self):
+        '''Save this table's cache file'''
         self.summary
         self.cache.save()
 
@@ -173,14 +199,62 @@ class Table:
 
 
     def add_column(self,column:Union[dict,_db_column_type]):
+        '''
+            Register a column instance with this table.
+
+            This does NOT literally add a column to the table in the database.
+            ----------
+
+            Arguments
+            -------------------------
+            `column` {Column,dict}
+                The column instance or dictionary of data to register.
+
+
+            Return {None}
+            ----------------------
+            None
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:35:18
+            `memberOf`: Table
+            `version`: 1.0
+            `method_name`: add_column
+            * @xxx [12-13-2022 12:36:52]: documentation for add_column
+        '''
         if isinstance(column,(dict)):
             column = _Column(self.database,self,column)
         self._columns.append(column)
 
     def gen_hash_id(self):
+        '''
+            Generate a hash_id specific for this table, if the table supports a hash_id column.
+            ----------
+
+            Return {str,None}
+            ----------------------
+            The hash_id if the table supports it, None otherwise.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 12:34:03
+            `memberOf`: Table
+            `version`: 1.0
+            `method_name`: gen_hash_id
+            * @xxx [12-13-2022 12:35:06]: documentation for gen_hash_id
+        '''
         if self.hash_id_prefix is not None:
             return f"{self.hash_id_prefix}_{_rand.rand((self._hash_id_column.validation.max_length - len(self.hash_id_prefix)))}"
 
+
+    # ---------------------------------------------------------------------------- #
+    #                            COLUMN SUPPORT METHODS                            #
+    # ---------------------------------------------------------------------------- #
+
+
     @property
     def columns(self)->Iterable[_db_column_type]:
         '''
@@ -225,6 +299,32 @@ class Table:
         '''
         self._columns = value
 
+    @property
+    def primary_id(self):
+        '''
+            Get this Table's primary_id column instance
+
+            `default`:None
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 12-13-2022 11:52:51
+            `@memberOf`: Table
+            `@property`: primary_id
+        '''
+        value = self._primary_id
+        if value is None:
+            for col in self.columns:
+                if col.is_primary:
+                    value = col
+                    self._primary_id = col
+                    break
+
+        return value
+
+
     @property
     def foreign_keys(self)->Iterable[_db_column_type]:
         output = []
@@ -479,13 +579,57 @@ class Table:
         '''
         self._has_modified_timestamp_column = value
 
-    def locate_special_columns(self):
-        for col in self.columns:
-            if col.data.is_hash_id:
-                self.has_hash_id = True
+    # def locate_special_columns(self):
+    #     for col in self.columns:
+    #         if col.data.is_hash_id:
+    #             self.has_hash_id = True
 
-    def insert(self,data:dict):
-        return self.database.insert_to_table(self.table_name,data)
+
+
+
+    # ---------------------------------------------------------------------------- #
+    #                             QUERY SUPPORT METHODS                            #
+    # ---------------------------------------------------------------------------- #
+
+
+    def insert(self,data:dict,**kwargs)->Union[int,dict,bool]:
+        '''
+            Insert a dictionary of data into this table
+            ----------
+
+            Arguments
+            -------------------------
+            `data` {dict}
+                The data to be inserted into this table, where the keys correspond to columns.
+
+            Keyword Arguments
+            -------------------------
+            [`return_row`=True] {bool}
+                If True, the entire row will be retrieved after a successful insertion and returned as a dictionary.
+
+            Return {int,dict,bool}
+            ----------------------
+            The integer id of the inserted row if successful, False otherwise.
+
+            if return_row is True, the row dictionary is returned.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-13-2022 11:43:55
+            `memberOf`: Table
+            `version`: 1.0
+            `method_name`: insert
+            * @TODO []: documentation for insert
+        '''
+        return_row = _obj.get_kwarg(['return_row'],True,(bool),**kwargs)
+        result = self.database.insert_to_table(self.table_name,data)
+        if result:
+            if return_row:
+                s = self.select_query()
+                s.add_where(self.primary_id.name,result,"=")
+                result = s.execute()
+        return result
 
     def select_query(self):
         '''Create a new select query instance for this table.'''
