@@ -3,6 +3,8 @@
 # pylint: disable=line-too-long
 # pylint: disable=unused-import
 
+# from typing import TYPE_CHECKING
+# from typing import TypeVar as _TypeVar
 
 
 # import colemen_utilities.database_utils.MySQL.MySQLDatabase as mysqlDB
@@ -13,10 +15,14 @@ from colemen_utilities.database_utils.MySQL.CacheFile import *
 from colemen_utilities.database_utils.MySQL.SelectQuery import *
 from colemen_utilities.database_utils.MySQL.UpdateQuery import *
 from colemen_utilities.database_utils.MySQL.DeleteQuery import *
+from colemen_utilities.database_utils.MySQL.Table import *
 
 from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase as MySQL
+from colemen_utilities.database_utils.MySQL.MySQLDatabase import new
 
 
-
+# if TYPE_CHECKING:
+#     import colemen_utilities.database_utils.MySQL.Table.Table as _table
+#     _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)
 
 
